@@ -1,3 +1,4 @@
+# ruff: noqa: E402
 import os
 
 # to prevent the webdriver manager from polluting logs
@@ -5,17 +6,16 @@ os.environ["WDM_LOG"] = "0"
 
 import json
 import logging
-import requests
 import sys
 from typing import Union
 
+import requests
 from fake_useragent import UserAgent
 from selenium import webdriver
 from webdriver_manager.chrome import ChromeDriverManager
 
 from discogs_alert import scrape as da_scrape, types as da_types
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -138,5 +138,4 @@ class AnonClient(Client):
         # pull & scrape page content
         url = f"{self._base_url_non_api}/sell/release/{release_id}?ev=rb&sort=price%2Casc"
         self.driver.get(url)
-        response_content = self.driver.page_source
-        return da_scrape.scrape_listings_from_marketplace(response_content)
+        return da_scrape.scrape_listings_from_marketplace(self.driver.page_source, release_id)
